# Mini_GUI_Games
### small funny games

## Installation
### Run command 
### `pip install mini_gui_games` 
### in terminal or command line to install package with games.

## Usage
### Use command `games` or `miniguigames` or `mini_gui_games` to show list of avaialable games.
### Run commands:

    bandergoose
    hanoitower
    snake
    tictactoe

### to launch the corresponding game

## Screenshots

### HannoiTower
![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/hanoitower1.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/hanoitower2.png?raw=true)
:--- | :---

### TicTacToe
![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/tictactoe1.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/tictactoe2.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/tictactoe3.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/tictactoe4.png?raw=true)
:--- | :--- | :--- | :--- 

### Snake
![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/snake1.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/snake2.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/snake3.png?raw=true)
:--- | :--- | :--- 

### BanderGoose
![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/bandergoose1.png?raw=true) | ![](https://github.com/Vskesha/Mini_GUI_Games/blob/main/screenshots/bandergoose2.png?raw=true)
:--- | :--- 
